pub enum WsStream {
Tungstenite(Box<WebSocketStream<MaybeTlsStream<TcpStream>>>),
AxumWebsocket(Box<WebSocket>),
}Expand description
A enum for different type of WebSocket stream.
honestly, this is a bit of a hack, but it works. The WebSocketStream in axum is derived from tungstenite, but axum does not expose the tungstenite stream.
Variants
Tungstenite(Box<WebSocketStream<MaybeTlsStream<TcpStream>>>)
Tungstenite WebSocket stream.
AxumWebsocket(Box<WebSocket>)
Axum WebSocket stream.